@@ -1,24 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 1999-2006 by Éric Bischoff <ebischoff@nerim.net>        *
- *   Copyright (C) 2007 by Albert Astals Cid <aacid@kde.org>               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 1999-2006 Éric Bischoff <ebischoff@nerim.net>
+    SPDX-FileCopyrightText: 2007 Albert Astals Cid <aacid@kde.org>
 
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <KLocalizedString>
 
+#include "toplevel.h"
 #include <KAboutData>
 #include <KCrash>
+#include <KDBusService>
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QCommandLineOption>
 #include <QDir>
-#include <KDBusService>
-#include "toplevel.h"
 
 #include "ktuberling_version.h"
 
@@ -41,7 +36,7 @@ int main(int argc, char *argv[])
   aboutData.addCredit(i18n("Bas Willems"), i18n("New artwork"), QStringLiteral("cybersurfer@euronet.nl"));
   aboutData.addCredit(i18n("Roger Larsson"), i18n("Sounds tuning"), QStringLiteral("roger.larsson@norran.net"));
   aboutData.addCredit(i18n("Dolores Almansa"), i18n("New artwork"), QStringLiteral("dolores.almansa@corazondemaria.org"));
-  aboutData.setHomepage(QStringLiteral("https://kde.org/applications/games/org.kde.ktuberling"));
+  aboutData.setHomepage(QStringLiteral("https://apps.kde.org/ktuberling"));
   QCommandLineParser parser;
   KAboutData::setApplicationData(aboutData);
   KCrash::initialize();
@@ -52,7 +47,7 @@ int main(int argc, char *argv[])
   aboutData.processCommandLine(&parser);
 
   KDBusService service;
-  TopLevel *toplevel=0;
+  TopLevel *toplevel=nullptr;
 
   if (app.isSessionRestored())
       kRestoreMainWindows<TopLevel>();
