@@ -1,12 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 1999-2006 by Éric Bischoff <ebischoff@nerim.net>        *
- *   Copyright (C) 2007-2008 by Albert Astals Cid <aacid@kde.org>          *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 1999-2006 Éric Bischoff <ebischoff@nerim.net>
+    SPDX-FileCopyrightText: 2007-2008 Albert Astals Cid <aacid@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /* Play ground widget */
 
@@ -39,7 +36,7 @@ static const char *saveGameText = "KTuberlingSaveGameV4";
 
 // Constructor
 PlayGround::PlayGround(PlayGroundCallbacks *callbacks, QWidget *parent)
-    : QGraphicsView(parent), m_callbacks(callbacks), m_newItem(0), m_dragItem(0), m_nextZValue(1), m_lockAspect(false), m_allowOnlyDrag(false)
+    : QGraphicsView(parent), m_callbacks(callbacks), m_newItem(nullptr), m_dragItem(nullptr), m_nextZValue(1), m_lockAspect(false), m_allowOnlyDrag(false)
 {
   setFrameStyle(QFrame::NoFrame);
   setOptimizationFlag(QGraphicsView::DontSavePainterState, true); // all items here save the painter state
@@ -51,7 +48,7 @@ PlayGround::PlayGround(PlayGroundCallbacks *callbacks, QWidget *parent)
 // Destructor
 PlayGround::~PlayGround()
 {
-  foreach (const SceneData &data, m_scenes)
+  for (const SceneData &data : std::as_const(m_scenes))
   {
     delete data.scene;
     delete data.undoStack;
@@ -62,7 +59,8 @@ PlayGround::~PlayGround()
 void PlayGround::reset()
 {
 
-  foreach(QGraphicsItem *item, scene()->items())
+  const QList<QGraphicsItem*> items = scene()->items();
+  for(QGraphicsItem *item : items)
   {
     ToDraw *currentObject = qgraphicsitem_cast<ToDraw *>(item);
     delete currentObject;
@@ -83,10 +81,11 @@ bool PlayGround::saveAs(const QString & name)
   out.setVersion(QDataStream::Qt_4_5);
   out << QString::fromLatin1(saveGameText);
   out << gameBoard.fileName();
-  foreach(QGraphicsItem *item, scene()->items())
+  const QList<QGraphicsItem*> items = scene()->items();
+  for(QGraphicsItem *item : items)
   {
     ToDraw *currentObject = qgraphicsitem_cast<ToDraw *>(item);
-    if (currentObject != NULL) currentObject->save(out);
+    if (currentObject != nullptr) currentObject->save(out);
   }
 
   return (f.error() == QFile::NoError);
@@ -257,7 +256,7 @@ void PlayGround::placeDraggedItem(const QPoint &pos)
   }
 
   setCursor(QCursor());
-  m_dragItem = 0;
+  m_dragItem = nullptr;
 }
 
 void PlayGround::placeNewItem(const QPoint &pos)
@@ -272,7 +271,7 @@ void PlayGround::placeNewItem(const QPoint &pos)
   } else {
     m_newItem->deleteLater();
   }
-  m_newItem = 0;
+  m_newItem = nullptr;
   setCursor(QCursor());
 }
 
@@ -318,10 +317,10 @@ void PlayGround::registerPlayGrounds()
 {
   QSet<QString> list;
   const QStringList dirs = FileFactory::locateAll(QStringLiteral("pics"));
-  Q_FOREACH (const QString &dir, dirs)
+  for (const QString &dir : dirs)
   {
     const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.theme"));
-    Q_FOREACH (const QString &file, fileNames)
+    for (const QString &file : fileNames)
     {
         list << dir + '/' + file;
     }
@@ -329,7 +328,7 @@ void PlayGround::registerPlayGrounds()
 
   QMultiMap<QString, QPair<QString, QPixmap>> sortedByName;
 
-  foreach(const QString &theme, list)
+  for(const QString &theme : std::as_const(list))
   {
     QFile layoutFile(theme);
     if (layoutFile.open(QIODevice::ReadOnly))
